""" Output file stuff """

from ldap_audit_tools.output.csv import add_csv_export_options
from ldap_audit_tools.output.csv import generate_csv_entries_output
from ldap_audit_tools.output.ldif import generate_ldif_entries_output


def add_export_options(parser, only_csv=False):
    """ Add CSV export options to an argparse.ArgumentParser instance """

    parser.add_argument(
        '-o', '--output',
        action='store',
        dest='output',
        help="Output CSV file path" if only_csv else "Output file path",
        default=None
    )

    if not only_csv:
        parser.add_argument(
            '-X', '--output-format',
            action='store',
            dest='output_format',
            help="Output file format",
            choices=('csv', 'ldif'),
            default='csv'
        )

    parser.add_argument(
        '--output-encoding',
        action='store',
        dest='output_encoding',
        help="Output file encoding (default: 'utf-8')",
        default='utf-8'
    )

    add_csv_export_options(parser)


def generate_entries_output(options, entries, attributes_names):
    """ Generate output file """

    if options.output_format == 'csv':
        generate_csv_entries_output(options, entries, attributes_names)
    elif options.output_format == 'ldif':
        generate_ldif_entries_output(options, entries, attributes_names)
    else:
        raise Exception(f'Invalid output file format "{options.output_format}"')
