""" LDAP entry source """

from ldap_audit_tools.source.ldap import add_ldap_options
from ldap_audit_tools.source.ldap import check_ldap_options
from ldap_audit_tools.source.ldap import get_ldap_entries
from ldap_audit_tools.source.ldif import add_ldif_options
from ldap_audit_tools.source.ldif import check_ldif_options
from ldap_audit_tools.source.ldif import get_ldif_entries

DEFAULT_ENCODING = 'utf-8'
DECODING_POLICIES = ('strict', 'ignore', 'xmlcharrefreplace', 'backslashreplace')
DEFAULT_DECODING_POLICY = 'backslashreplace'


def add_source_options(parser):
    """ Add LDAP entry source options to an argparse.ArgumentParser instance """

    parser.add_argument(
        '-e', '--encoding',
        action="store",
        type=str,
        dest="encoding",
        help=f'LDAP source encoding (default: {DEFAULT_ENCODING})',
        default=DEFAULT_ENCODING
    )

    parser.add_argument(
        '-E', '--decoding-policy',
        action="store",
        type=str, choices=DECODING_POLICIES,
        dest="decoding_policy",
        help=(
            f'LDAP source decoding policy (default: {DEFAULT_DECODING_POLICY})'
        ),
        default=DEFAULT_DECODING_POLICY
    )

    add_ldap_options(parser)
    add_ldif_options(parser)


def check_source_options(parser, options):
    """ Check validty of  LDAP entry source options in an argparse.Namespace instance """
    ldap_source = check_ldap_options(options)
    ldif_source = check_ldif_options(options)
    if ldap_source and ldif_source:
        parser.error('Multiple LDAP entry source configured')
    if not ldap_source and not ldif_source:
        parser.error('No LDAP entry source configured')


def get_entries(options):
    """ Get LDAP entries form configured sources """
    return get_ldap_entries(options) or get_ldif_entries(options)
