""" LDIF file helpers """

import logging
import ldif


log = logging.getLogger(__name__)


def add_ldif_options(parser):
    """ Add LDIF file options to an argparse.ArgumentParser instance """

    ldif_opts = parser.add_argument_group("LDIF options")

    ldif_opts.add_argument(
        '-i', '--input',
        action="store",
        type=str,
        dest="input",
        help="Input LDIF file"
    )

    return ldif_opts


def check_ldif_options(options):
    """ Check validty of LDIF file options in an argparse.Namespace instance """
    return bool(options.input)


def get_ldif_entries(options):
    """
    Get LDIF entries

    :param options: The options of the current script (argparse.Namespace)

    return dict of LDAP entries or False if no LDAP source configured
    """
    if not options.input:
        return False

    # Open/parse LDIF file
    with open(options.input, mode='r', encoding=options.encoding) as file_descriptor:
        log.info('Parse LDIF file...')
        ldif_file = ldif.LDIFRecordList(file_descriptor)
        ldif_file.parse()

    return dict(
        (entry_dn, entry)
        for entry_dn, entry in ldif_file.all_records
    )
